@@ -14,15 +14,15 @@
 # limitations under the License.
 #
 
-as.list.iter <- function(x, ...) {
-  n <- 64
-  a <- vector('list', length=n)
+as.list.iter <- function(x, n=as.integer(2^31-1), ...) {
+  size <- 64
+  a <- vector('list', length=size)
   i <- 0
   tryCatch({
-    repeat {
-      if (i >= n) {
-        n <- 2 * n
-        length(a) <- n
+    while (i < n) {
+      if (i >= size) {
+        size <- min(2 * size, n)
+        length(a) <- size
       }
       a[i + 1] <- list(nextElem(x))
       i <- i + 1
