@@ -12,7 +12,7 @@ options(showWarnCalls=TRUE)
 cat('Starting test at', date(), '\n')
 
 tests <- c('test.R', 'iapplyTest.R', 'isplitTest.R',
-           'icountnTest.R')
+           'icountnTest.R', 'chunksizeTest.R', 'recycleTest.R')
 
 errcase <- list()
 for (f in tests) {
